==> wyvern-2.1.2.tar.bz2: wyvern-2.1.2/util/suexec.h <==
/*****************************************************************************
 *
 * FILE:	suexec.h
 * DESCRIPTION:	user-definable variable for the suexec wrapper code
 * DATE:	Fri, Nov 29 2002
 * AUTHOR:	Kouichi ABE (WALL) / 
 * E-MAIL:	kouichi@MysticWALL.COM
 * URL:		http://www.MysticWALL.COM/cover.html
 * COPYRIGHT:	(C) 2002 졿Kouichi ABE (WALL), All rights reserved.
 * LICENSE:
 *  Copyright (C) 2002 Kouichi ABE (WALL) <kouichi@MysticWALL.COM>,
 *  All rights reserved.
 *  
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *   THIS SOFTWARE IS PROVIDED BY KOUICHI ABE (WALL) ``AS IS'' AND ANY
 *   EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL KOUICHI ABE (WALL) BE
 *   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 *   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 *   BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *   WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 *   OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 *   IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: suexec.h,v 1.1.2.3 2003/11/28 16:06:53 kouichi Exp $
 *
 *****************************************************************************/

#ifndef	_MOD_SUEXEC_H
#define	_MOD_SUEXEC_H

#ifndef	TRUE
#define	TRUE	1
#endif	/* TRUE */
#ifndef	FALSE
#define	FALSE	0
#endif	/* FALSE */

/*
 * HTTPD_USER:	user that the Web server runs as
 */
#ifndef	HTTPD_USER
#define	HTTPD_USER	"www"
#endif	/* HTTPD_USER */

/*
 * HTTPD_GROUP:	group that the Web server runs as
 */
#ifndef	HTTPD_GROUP
#define	HTTPD_GROUP	"www"
#endif	/* HTTPD_GROUP */

/*
 * UID_MIN:	lowest UID that we will suid to
 */
#ifndef	UID_MIN
#define	UID_MIN	(100)
#endif	/* UID_MIN */

/*
 * GID_MIN:	lowest GID that we will suid to
 */
#ifndef	GID_MIN
#define	GID_MIN	(100)
#endif	/* GID_MIN */

/*
 * SAFE_PATH:	safe PATH environment to pass to CGI executables
 */
#ifndef	SAFE_PATH
#define	SAFE_PATH	"/bin:/usr/bin:/usr/local/bin"
#endif	/* SAFE_PATH */

/*****************************************************************************/

/*
 * LOG_FILE:	log what suexec does.
 */
#ifndef	LOG_FILE
#ifdef	SERVER_ROOT
#define	LOG_FILE	SERVER_ROOT "/logs/suexec.log"
#else
#define	LOG_FILE	"/var/log/httpd-suexec.log"
#endif	/* SERVER_ROOT */
#endif	/* LOG_FILE */


/*****************************************************************************/

/*
 * RESOURCE LIMITS -- hard and soft.  Set to RLIM_INFINITY for no limits.
 * Soft limits can be increased by the application.  Hard limits cannot be
 * changed.
 */
#ifndef SET_LIMITS
#define SET_LIMITS FALSE
#endif

#define ONEK	(1024)

/* priority */
#ifndef PRIORITY
#define PRIORITY	(10)
#endif

/* maximum CPU time */
#ifndef LIMIT_CPU_HARD
#define LIMIT_CPU_HARD	(120)	/* CPU seconds */
#endif

#ifndef LIMIT_CPU_SOFT
#define LIMIT_CPU_SOFT	(10)	/* CPU seconds */
#endif

/* maximum size of a single file that can be created (blocks) */
#ifndef LIMIT_FSIZE_HARD
#define LIMIT_FSIZE_HARD	(2048 * ONEK)	/* two megabytes */
#endif

#ifndef LIMIT_FSIZE_SOFT
#define LIMIT_FSIZE_SOFT	(100 * ONEK)	/* 100K */
#endif

/* maximum amount of in-memory data */
#ifndef LIMIT_DATA_HARD
#define LIMIT_DATA_HARD	(8192 * ONEK)	/* eight megabytes */
#endif

#ifndef LIMIT_DATA_SOFT
#define LIMIT_DATA_SOFT	(1024 * ONEK)	/* one megabyte */
#endif

/* maximum stack size */
#ifndef LIMIT_STACK_HARD
#define LIMIT_STACK_HARD	(8192 * ONEK)	/* eight megabytes */
#endif

#ifndef LIMIT_STACK_SOFT
#define LIMIT_STACK_SOFT	(1024 * ONEK)	/* one megabyte */
#endif

/* core dump size */
#ifndef LIMIT_CORE_HARD
#define LIMIT_CORE_HARD	(0)	/* don't allow core dumps */
#endif

#ifndef LIMIT_CORE_SOFT
#define LIMIT_CORE_SOFT	(0)	/* don't allow core dumps */
#endif

/* maximum memory ("resident set") usage */
#ifndef LIMIT_RSS_HARD
#define LIMIT_RSS_HARD	(8192 * ONEK)	/* eight megs */
#endif

#ifndef LIMIT_RSS_SOFT
#define LIMIT_RSS_SOFT	(1024 * ONEK)	/* one meg */
#endif

/* max number of processes script can spawn */
#ifndef LIMIT_NPROC_HARD
#define LIMIT_NPROC_HARD	(256)
#endif

#ifndef LIMIT_NPROC_SOFT
#define LIMIT_NPROC_SOFT	(32)
#endif

/* max number of open file descriptors */
#ifndef LIMIT_NOFILE_HARD
#define LIMIT_NOFILE_HARD	(256)
#endif

#ifndef LIMIT_NOFILE_SOFT
#define LIMIT_NOFILE_SOFT	(32)
#endif

#endif	/* _MOD_SUEXEC_H */

==> wyvern-2.2.10.tar.bz2: wyvern-2.2.10/util/suexec.h <==
/*****************************************************************************
 *
 * FILE:	suexec.h
 * DESCRIPTION:	Wyvern: user-definable variable for the suexec wrapper code
 * DATE:	Fri, Nov 29 2002
 * UPDATE:	Wed, Sep 22 2004
 * AUTHOR:	Kouichi ABE (WALL) / 
 * E-MAIL:	kouichi@MysticWALL.COM
 * URL:		http://www.MysticWALL.COM/
 * COPYRIGHT:	(c) 2002-2004 졿Kouichi ABE (WALL), All rights reserved.
 * LICENSE:
 *
 *  Copyright (c) 2002-2004 Kouichi ABE (WALL) <kouichi@MysticWALL.COM>,
 *  All rights reserved.
 *  
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *	documentation and/or other materials provided with the distribution.
 *
 *   THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 *   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 *   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE
 *   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 *   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *   INTERRUPTION)  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 *   THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: suexec.h,v 1.5 2004/09/22 11:13:41 kouichi Exp $
 *
 *****************************************************************************/

#ifndef	_SUEXEC_H
#define	_SUEXEC_H

#ifndef	TRUE
#define	TRUE	1
#endif	/* TRUE */
#ifndef	FALSE
#define	FALSE	0
#endif	/* FALSE */

/*
 * HTTPD_USER:	user that the Web server runs as
 */
#ifndef	HTTPD_USER
#define	HTTPD_USER	"www"
#endif	/* HTTPD_USER */

/*
 * HTTPD_GROUP:	group that the Web server runs as
 */
#ifndef	HTTPD_GROUP
#define	HTTPD_GROUP	"www"
#endif	/* HTTPD_GROUP */

/*
 * UID_MIN:	lowest UID that we will suid to
 */
#ifndef	UID_MIN
#define	UID_MIN	(100)
#endif	/* UID_MIN */

/*
 * GID_MIN:	lowest GID that we will suid to
 */
#ifndef	GID_MIN
#define	GID_MIN	(100)
#endif	/* GID_MIN */

/*
 * SAFE_PATH:	safe PATH environment to pass to CGI executables
 */
#ifndef	SAFE_PATH
#define	SAFE_PATH	"/bin:/usr/bin:/usr/local/bin"
#endif	/* SAFE_PATH */

/*****************************************************************************/

/*
 * LOG_FILE:	log what suexec does.
 */
#ifndef	LOG_FILE
#ifdef	SERVER_ROOT
#define	LOG_FILE	SERVER_ROOT "/logs/httpd-suexec.log"
#else
#define	LOG_FILE	"/var/log/httpd-suexec.log"
#endif	/* SERVER_ROOT */
#endif	/* LOG_FILE */


/*****************************************************************************/

/*
 * RESOURCE LIMITS -- hard and soft.  Set to RLIM_INFINITY for no limits.
 * Soft limits can be increased by the application.  Hard limits cannot be
 * changed.
 */
#ifndef SET_LIMITS
#define SET_LIMITS FALSE
#endif

#define ONEK	(1024)

/* priority */
#ifndef PRIORITY
#define PRIORITY	(10)
#endif

/* maximum CPU time */
#ifndef LIMIT_CPU_HARD
#define LIMIT_CPU_HARD	(120)	/* CPU seconds */
#endif

#ifndef LIMIT_CPU_SOFT
#define LIMIT_CPU_SOFT	(10)	/* CPU seconds */
#endif

/* maximum size of a single file that can be created (blocks) */
#ifndef LIMIT_FSIZE_HARD
#define LIMIT_FSIZE_HARD	(2048 * ONEK)	/* two megabytes */
#endif

#ifndef LIMIT_FSIZE_SOFT
#define LIMIT_FSIZE_SOFT	(100 * ONEK)	/* 100K */
#endif

/* maximum amount of in-memory data */
#ifndef LIMIT_DATA_HARD
#define LIMIT_DATA_HARD	(8192 * ONEK)	/* eight megabytes */
#endif

#ifndef LIMIT_DATA_SOFT
#define LIMIT_DATA_SOFT	(1024 * ONEK)	/* one megabyte */
#endif

/* maximum stack size */
#ifndef LIMIT_STACK_HARD
#define LIMIT_STACK_HARD	(8192 * ONEK)	/* eight megabytes */
#endif

#ifndef LIMIT_STACK_SOFT
#define LIMIT_STACK_SOFT	(1024 * ONEK)	/* one megabyte */
#endif

/* core dump size */
#ifndef LIMIT_CORE_HARD
#define LIMIT_CORE_HARD	(0)	/* don't allow core dumps */
#endif

#ifndef LIMIT_CORE_SOFT
#define LIMIT_CORE_SOFT	(0)	/* don't allow core dumps */
#endif

/* maximum memory ("resident set") usage */
#ifndef LIMIT_RSS_HARD
#define LIMIT_RSS_HARD	(8192 * ONEK)	/* eight megs */
#endif

#ifndef LIMIT_RSS_SOFT
#define LIMIT_RSS_SOFT	(1024 * ONEK)	/* one meg */
#endif

/* max number of processes script can spawn */
#ifndef LIMIT_NPROC_HARD
#define LIMIT_NPROC_HARD	(256)
#endif

#ifndef LIMIT_NPROC_SOFT
#define LIMIT_NPROC_SOFT	(32)
#endif

/* max number of open file descriptors */
#ifndef LIMIT_NOFILE_HARD
#define LIMIT_NOFILE_HARD	(256)
#endif

#ifndef LIMIT_NOFILE_SOFT
#define LIMIT_NOFILE_SOFT	(32)
#endif

#endif	/* _SUEXEC_H */
